@@ -158,17 +158,27 @@ AssetListWidget::AssetListWidget(bool isEffect, QWidget *parent)
     QWidget *empty = new QWidget(this);
     empty->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     m_toolbar->addWidget(empty);
-    QAction *showInfo = new QAction(this);
+    // Include list
+    QAction *includeList = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), QString(), this);
+    includeList->setCheckable(true);
+    // Disable include list on startup until ready
+    KdenliveSettings::setEnableAssetsIncludeList(false);
+    includeList->setChecked(KdenliveSettings::enableAssetsIncludeList());
+    connect(includeList, &QAction::triggered, this, [this](bool enable) {
+        KdenliveSettings::setEnableAssetsIncludeList(enable);
+        m_proxyModel->updateIncludeList();
+    });
+    includeList->setToolTip(i18n("Only show reviewed assets"));
+    m_toolbar->addAction(includeList);
+    // Asset Info
+    QAction *showInfo = new QAction(QIcon::fromTheme(QStringLiteral("help-about")), QString(), this);
     showInfo->setCheckable(true);
-    showInfo->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
     showInfo->setToolTip(m_isEffect ? i18n("Show/hide description of the effects") : i18n("Show/hide description of the compositions"));
     m_toolbar->addAction(showInfo);
     m_lay->addWidget(m_toolbar);
 
     // Search line
     m_searchLine = new QLineEdit(this);
-    m_searchLine->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
-    // m_searchLine->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     m_searchLine->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     m_searchLine->setClearButtonEnabled(true);
     m_searchLine->setPlaceholderText(i18n("Search…"));
@@ -177,10 +187,9 @@ AssetListWidget::AssetListWidget(bool isEffect, QWidget *parent)
     connect(m_searchLine, &QLineEdit::textChanged, this, [this](const QString &str) { setFilterName(str); });
     m_lay->addWidget(m_searchLine);
 
-    setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     setAcceptDrops(true);
     m_effectsTree = new QTreeView(this);
-    m_effectsTree->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+    m_effectsTree->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
     m_effectsTree->setHeaderHidden(true);
     m_effectsTree->setAlternatingRowColors(true);
     m_effectsTree->setRootIsDecorated(true);
