@@ -43,6 +43,8 @@ public:
 
     /** Returns true is the effect can use keyframes */
     bool keyframesAllowed() const;
+    /** @brief Returns true is the model has more than one keyframe */
+    bool hasMultipleKeyframes() const;
     /** Returns true is the keyframes should be hidden on first opening*/
     bool modelHideKeyframes() const;
     /** Returns the preset menu to be embedded in toolbars */
@@ -91,7 +93,7 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void seekToPos(int);
-    void initKeyframeView(bool active);
+    void initKeyframeView(bool active, bool outside);
     /** @brief clear and refill the effect presets */
     void updatePresets(const QString &presetName = QString());
     void updateHeight();
