@@ -38,7 +38,6 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QProcessEnvironment>
 #include <QToolBar>
 #include <QVBoxLayout>
-#include <kio_version.h>
 
 MediaBrowser::MediaBrowser(QWidget *parent)
     : QWidget(parent)
@@ -64,7 +63,6 @@ MediaBrowser::MediaBrowser(QWidget *parent)
     m_op = new KDirOperator(QUrl(), parent);
     m_op->dirLister()->setAutoUpdate(false);
     // Ensure shortcuts are only active on this widget to avoid conflicts with app shortcuts
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     QList<QAction *> actions = m_op->allActions();
     QAction *trash = m_op->action(KDirOperator::Trash);
     QAction *up = m_op->action(KDirOperator::Up);
@@ -73,16 +71,7 @@ MediaBrowser::MediaBrowser(QWidget *parent)
     QAction *inlinePreview = m_op->action(KDirOperator::ShowPreviewPanel);
     QAction *preview = m_op->action(KDirOperator::ShowPreviewPanel);
     QAction *viewMenu = m_op->action(KDirOperator::ViewModeMenu);
-#else
-    QList<QAction *> actions = m_op->actionCollection()->actions();
-    QAction *trash = m_op->actionCollection()->action("trash");
-    QAction *up = m_op->actionCollection()->action("up");
-    QAction *back = m_op->actionCollection()->action("back");
-    QAction *forward = m_op->actionCollection()->action("forward");
-    QAction *inlinePreview = m_op->actionCollection()->action("inline preview");
-    QAction *preview = m_op->actionCollection()->action("preview");
-    QAction *viewMenu = m_op->actionCollection()->action("view menu");
-#endif
+
     // Disable "Del" shortcut to move item to trash - too dangerous ??
     trash->setShortcut({});
     // Plug actions
@@ -125,11 +114,7 @@ MediaBrowser::MediaBrowser(QWidget *parent)
     });
     KConfigGroup grp(KSharedConfig::openConfig(), "Media Browser");
     m_op->readConfig(grp);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     m_op->setViewMode(KFile::Default);
-#else
-    m_op->setView(KFile::Default);
-#endif
     m_op->setMode(KFile::ExistingOnly | KFile::Files | KFile::Directory);
     m_op->setIconSize(KdenliveSettings::mediaIconSize());
     m_filterCombo = new KFileFilterCombo(this);
@@ -283,11 +268,7 @@ void MediaBrowser::slotViewDoubleClicked()
 
 void MediaBrowser::detectShortcutConflicts()
 {
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     QList<QAction *> actions = m_op->allActions();
-#else
-    QList<QAction *> actions = m_op->actionCollection()->actions();
-#endif
     QList<QKeySequence> shortcutsList;
     m_browserActions.clear();
     m_conflictingAppActions.clear();
@@ -485,7 +466,7 @@ void MediaBrowser::slotLocationChanged(const QString &text)
 
 void MediaBrowser::openExternalFile(const QUrl &url)
 {
-    if (pCore->packageType() == QStringLiteral("appimage")) {
+    if (pCore->packageType() == LinuxPackageType::AppImage) {
         qDebug() << "::::: LAUNCHING APPIMAGE BROWSER.........";
         QProcess process;
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
