@@ -48,6 +48,7 @@ class ProjectClip : public AbstractProjectItem, public ClipController
 
 public:
     friend class Bin;
+    friend class KdenliveTests;
     friend bool TimelineModel::checkConsistency(const std::vector<int> &guideSnaps); // for testing
     /**
      * @brief Constructor; used when loading a project and the producer is already available.
@@ -95,7 +96,7 @@ public:
     ~ProjectClip() override;
 
     void reloadProducer(bool refreshOnly = false, bool isProxy = false, bool forceAudioReload = false) override;
-
+    void setThumbFrame(int frame) override;
     /** @brief Returns a unique hash identifier used to store clip thumbnails. */
     // virtual void hash() = 0;
 
@@ -149,6 +150,8 @@ public:
 
     /** @brief Returns the original clip's fps. */
     double getOriginalFps() const;
+    /** @brief Returns the original clip's fps as {frame_rate_num, frame_rate_den}. */
+    std::pair<int, int> fpsInfo() const;
 
     bool rename(const QString &name, int column) override;
 
@@ -364,7 +367,7 @@ private:
     const QString getFileHash();
     QMutex m_producerMutex;
     QMutex m_thumbMutex;
-    QString m_thumbXml;
+    QByteArray m_thumbXml;
     const QString geometryWithOffset(const QString &data, int offset);
     QMap <QString, QByteArray> m_audioLevels;
     /** @brief If true, all timeline occurrences of this clip will be replaced from a fresh producer on reload. */
