@@ -32,9 +32,9 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "timeline2/view/timelinewidget.h"
 #include <mlt++/MltRepository.h>
 
-#include "utils/KMessageBox_KdenliveCompat.h"
 #include <KIO/OpenFileManagerWindowJob>
 #include <KMessageBox>
+
 #include <QCoreApplication>
 #include <QDesktopServices>
 #include <QDir>
@@ -47,7 +47,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #endif
 
 std::unique_ptr<Core> Core::m_self;
-Core::Core(const QString &packageType)
+Core::Core(LinuxPackageType packageType)
     : audioThumbCache(QStringLiteral("audioCache"), 2000000)
     , taskManager(this)
     , m_packageType(packageType)
@@ -77,7 +77,7 @@ void Core::finishShutdown()
 
 Core::~Core() {}
 
-bool Core::build(const QString &packageType, bool testMode)
+bool Core::build(LinuxPackageType packageType, bool testMode)
 {
     if (m_self) {
         return true;
@@ -148,7 +148,7 @@ void Core::initHeadless(const QUrl &url)
     QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadHeadless", Qt::QueuedConnection, Q_ARG(QUrl, url));
 }
 
-void Core::initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, const QString &clipsToLoad)
+void Core::initGUI(const QString &MltPath, const QUrl &Url, const QString &clipsToLoad)
 {
     m_mainWindow = new MainWindow();
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
@@ -187,6 +187,7 @@ void Core::initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, cons
     projectManager()->init(Url, clipsToLoad);
 
     // The MLT Factory will be initiated there, all MLT classes will be usable only after this
+    bool inSandbox = m_packageType == LinuxPackageType::AppImage || m_packageType == LinuxPackageType::Flatpak || m_packageType == LinuxPackageType::Snap;
     if (inSandbox) {
         // In a sandbox environment we need to search some paths recursively
         QString appPath = qApp->applicationDirPath();
@@ -338,7 +339,7 @@ QString Core::openExternalApp(QString appPath, QStringList args)
     process.setProgram(appPath);
 #endif
     process.setArguments(args);
-    if (pCore->packageType() == QStringLiteral("appimage")) {
+    if (pCore->packageType() == LinuxPackageType::AppImage) {
         // Strip appimage custom LD_LIBRARY_PATH...
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         qDebug() << "::: GOT ENV: " << env.value("LD_LIBRARY_PATH") << ", PATH: " << env.value("PATH");
@@ -574,6 +575,11 @@ Mlt::Profile &Core::getProjectProfile()
     return m_projectProfile;
 }
 
+std::pair<int, int> Core::getProjectFpsInfo() const
+{
+    return {m_projectProfile.frame_rate_num(), m_projectProfile.frame_rate_den()};
+}
+
 void Core::updateMonitorProfile()
 {
     m_monitorProfile.set_colorspace(m_projectProfile.colorspace());
@@ -862,6 +868,27 @@ int Core::getItemTrack(const ObjectId &id)
     return 0;
 }
 
+bool Core::itemContainsPos(const ObjectId &id, int pos)
+{
+    if (!m_guiConstructed || (!id.uuid.isNull() && !m_mainWindow->getTimeline(id.uuid))) return false;
+    switch (id.type) {
+    case KdenliveObjectType::TimelineClip:
+    case KdenliveObjectType::TimelineComposition:
+    case KdenliveObjectType::TimelineMix: {
+        int itemPos = getItemPosition(id);
+        if (pos < itemPos) {
+            return false;
+        }
+        if (pos >= itemPos + getItemDuration(id)) {
+            return false;
+        }
+        return true;
+    }
+    default:
+        return true;
+    }
+}
+
 void Core::refreshProjectItem(const ObjectId &id)
 {
     if (!m_guiConstructed || (!id.uuid.isNull() && !m_mainWindow->getTimeline(id.uuid))) return;
@@ -887,7 +914,8 @@ void Core::refreshProjectItem(const ObjectId &id)
             m_monitorManager->activateMonitor(Kdenlive::ClipMonitor);
             m_monitorManager->refreshClipMonitor(true);
         }
-        if (m_monitorManager->projectMonitorVisible() && m_mainWindow->getCurrentTimeline()->controller()->refreshIfVisible(id.itemId)) {
+        if (m_monitorManager->projectMonitorVisible() && m_mainWindow->getCurrentTimeline() &&
+            m_mainWindow->getCurrentTimeline()->controller()->refreshIfVisible(id.itemId)) {
             m_monitorManager->refreshTimer.start();
         }
         break;
@@ -1050,19 +1078,26 @@ void Core::invalidateRange(QPair<int, int> range)
 void Core::invalidateItem(ObjectId itemId)
 {
     if (!m_guiConstructed || !m_mainWindow->getCurrentTimeline() || m_mainWindow->getCurrentTimeline()->loading) return;
+    auto tl = m_mainWindow->getTimeline(itemId.uuid);
     switch (itemId.type) {
     case KdenliveObjectType::TimelineClip:
     case KdenliveObjectType::TimelineComposition:
-        m_mainWindow->getCurrentTimeline()->controller()->invalidateItem(itemId.itemId);
+        if (tl) {
+            tl->controller()->invalidateItem(itemId.itemId);
+        }
         break;
     case KdenliveObjectType::TimelineTrack:
-        m_mainWindow->getCurrentTimeline()->controller()->invalidateTrack(itemId.itemId);
+        if (tl) {
+            tl->controller()->invalidateTrack(itemId.itemId);
+        }
         break;
     case KdenliveObjectType::BinClip:
         m_mainWindow->getBin()->invalidateClip(QString::number(itemId.itemId));
         break;
     case KdenliveObjectType::Master:
-        m_mainWindow->getCurrentTimeline()->model()->invalidateZone(0, -1);
+        if (tl) {
+            tl->model()->invalidateZone(0, -1);
+        }
         break;
     default:
         // compositions should not have effects
@@ -1070,33 +1105,60 @@ void Core::invalidateItem(ObjectId itemId)
     }
 }
 
-double Core::getClipSpeed(int id) const
+double Core::getClipSpeed(ObjectId id) const
 {
-    return m_mainWindow->getCurrentTimeline()->model()->getClipSpeed(id);
+    auto tl = m_mainWindow->getTimeline(id.uuid);
+    if (tl) {
+        return tl->model()->getClipSpeed(id.itemId);
+    }
+    return 1.;
 }
 
 void Core::updateItemKeyframes(ObjectId id)
 {
     if (id.type == KdenliveObjectType::TimelineClip && m_guiConstructed) {
-        m_mainWindow->getCurrentTimeline()->controller()->updateClip(id.itemId, {TimelineModel::KeyframesRole});
+        auto tl = m_mainWindow->getTimeline(id.uuid);
+        if (tl) {
+            tl->controller()->updateClip(id.itemId, {TimelineModel::KeyframesRole});
+        }
     }
 }
 
-void Core::updateItemModel(ObjectId id, const QString &service)
+void Core::updateItemModel(ObjectId id, const QString &service, const QString &updatedParam)
 {
     if (m_guiConstructed && id.type == KdenliveObjectType::TimelineClip && !m_mainWindow->getCurrentTimeline()->loading &&
         service.startsWith(QLatin1String("fade"))) {
-        bool startFade = service.startsWith(QLatin1String("fadein")) || service.startsWith(QLatin1String("fade_from_"));
-        m_mainWindow->getCurrentTimeline()->controller()->updateClip(id.itemId, {startFade ? TimelineModel::FadeInRole : TimelineModel::FadeOutRole});
+        auto tl = m_mainWindow->getTimeline(id.uuid);
+        if (tl) {
+            bool startFade = service.startsWith(QLatin1String("fadein")) || service.startsWith(QLatin1String("fade_from_"));
+            QVector<int> roles;
+            if (startFade) {
+                roles = {TimelineModel::FadeInRole, TimelineModel::FadeInMethodRole};
+                if (updatedParam == QLatin1String("alpha") || updatedParam == QLatin1String("level")) {
+                    roles << TimelineModel::FadeInMethodRole;
+                }
+            } else {
+                roles = {TimelineModel::FadeOutRole, TimelineModel::FadeOutMethodRole};
+                if (updatedParam == QLatin1String("alpha") || updatedParam == QLatin1String("level")) {
+                    roles << TimelineModel::FadeOutMethodRole;
+                }
+            }
+            qDebug() << "==== UPDATING FADE ROLES";
+            tl->controller()->updateClip(id.itemId, roles);
+        }
     }
 }
 
 void Core::showClipKeyframes(ObjectId id, bool enable)
 {
+    auto tl = m_mainWindow->getTimeline(id.uuid);
+    if (!tl) {
+        return;
+    }
     if (id.type == KdenliveObjectType::TimelineClip) {
-        m_mainWindow->getCurrentTimeline()->controller()->showClipKeyframes(id.itemId, enable);
+        tl->controller()->showClipKeyframes(id.itemId, enable);
     } else if (id.type == KdenliveObjectType::TimelineComposition) {
-        m_mainWindow->getCurrentTimeline()->controller()->showCompositionKeyframes(id.itemId, enable);
+        tl->controller()->showCompositionKeyframes(id.itemId, enable);
     }
 }
 
@@ -1269,13 +1331,14 @@ QString Core::getProjectCaptureFolderName()
     return QString();
 }
 
-QString Core::getTimelineClipBinId(int cid)
+QString Core::getTimelineClipBinId(ObjectId id)
 {
     if (!m_guiConstructed) {
         return QString();
     }
-    if (m_mainWindow->getCurrentTimeline()->model()->isClip(cid)) {
-        return m_mainWindow->getCurrentTimeline()->model()->getClipBinId(cid);
+    auto tl = m_mainWindow->getTimeline(id.uuid);
+    if (tl && tl->model()->isClip(id.itemId)) {
+        return tl->model()->getClipBinId(id.itemId);
     }
     return QString();
 }
@@ -1393,8 +1456,11 @@ void Core::setWidgetKeyBinding(const QString &mess)
 
 void Core::showEffectZone(ObjectId id, QPair<int, int> inOut, bool checked)
 {
-    if (m_guiConstructed && m_mainWindow->getCurrentTimeline() && m_mainWindow->getCurrentTimeline()->controller() && id.type != KdenliveObjectType::BinClip) {
-        m_mainWindow->getCurrentTimeline()->controller()->showRulerEffectZone(inOut, checked);
+    if (m_guiConstructed && id.type != KdenliveObjectType::BinClip) {
+        auto tl = m_mainWindow->getTimeline(id.uuid);
+        if (tl) {
+            tl->controller()->showRulerEffectZone(inOut, checked);
+        }
     }
 }
 
@@ -1411,9 +1477,12 @@ void Core::testProxies()
     dialog->exec();
 }
 
-void Core::resizeMix(int cid, int duration, MixAlignment align, int leftFrames)
+void Core::resizeMix(const ObjectId id, int duration, MixAlignment align, int leftFrames)
 {
-    m_mainWindow->getCurrentTimeline()->controller()->resizeMix(cid, duration, align, leftFrames);
+    auto tl = m_mainWindow->getTimeline(id.uuid);
+    if (tl) {
+        tl->controller()->resizeMix(id.itemId, duration, align, leftFrames);
+    }
 }
 
 MixAlignment Core::getMixAlign(const ObjectId &itemInfo) const
@@ -1447,13 +1516,6 @@ void Core::cleanup()
     }
 }
 
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 98, 0)
-int Core::getNewStuff(const QString &config)
-{
-    return m_mainWindow->getNewStuff(config);
-}
-#endif
-
 void Core::addBin(const QString &id)
 {
     Bin *bin = new Bin(m_projectItemModel, m_mainWindow, false);
@@ -1554,17 +1616,17 @@ void Core::groupAssetMultiKeyframeCommand(const ObjectId &id, const QString &ass
     }
 }
 
-void Core::removeGroupEffect(const ObjectId &id, const QString &assetId)
+void Core::removeGroupEffect(const ObjectId &id, const QString &assetId, int originalId)
 {
     switch (id.type) {
     case KdenliveObjectType::TimelineClip:
         if (auto tl = currentDoc()->getTimeline(id.uuid)) {
-            tl->removeEffectFromGroup(id.itemId, assetId);
+            tl->removeEffectFromGroup(id.itemId, assetId, originalId);
         }
         break;
     case KdenliveObjectType::BinClip:
         if (bin() != nullptr) {
-            bin()->removeEffectFromGroup(assetId);
+            bin()->removeEffectFromGroup(id.itemId, assetId, originalId);
         }
         break;
     default:
@@ -1607,9 +1669,16 @@ void Core::highlightFileInExplorer(QList<QUrl> urls)
     if (urls.isEmpty()) {
         return;
     }
-    if (m_packageType == QLatin1String("flatpak")) {
+    if (m_packageType == LinuxPackageType::Flatpak) {
         QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(urls.first().toLocalFile()).absolutePath()));
     } else {
         KIO::highlightInFileManager(urls);
     }
 }
+
+void Core::updateHoverItem(const QUuid &uuid)
+{
+    if (m_guiConstructed && uuid == m_mainWindow->getCurrentTimeline()->getUuid()) {
+        m_mainWindow->getCurrentTimeline()->regainFocus();
+    }
+}
