@@ -5,11 +5,11 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "kdenlivesettingsdialog.h"
-#include "filefilter.h"
 #include "core.h"
 #include "dialogs/customcamcorderdialog.h"
 #include "dialogs/profilesdialog.h"
 #include "doc/kdenlivedoc.h"
+#include "filefilter.h"
 #include "kdenlivesettings.h"
 #include "mainwindow.h"
 #include "monitor/monitor.h"
@@ -33,15 +33,8 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <KArchiveDirectory>
 #include <KIO/DesktopExecParser>
 #include <KIO/FileCopyJob>
-#include <KIO/OpenFileManagerWindowJob>
-#include <kio/directorysizejob.h>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
-#include "utils/KMessageBox_KdenliveCompat.h"
+#include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
 #include <KLineEdit>
 #include <KMessageBox>
@@ -50,6 +43,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <KTar>
 #include <KUrlRequesterDialog>
 #include <KZip>
+#include <kio/directorysizejob.h>
 
 #include <QAction>
 #include <QButtonGroup>
@@ -310,7 +304,7 @@ void KdenliveSettingsDialog::initProxyPage()
     m_configProxy.setupUi(p10);
     m_proxyProfiles = new EncodingProfilesChooser(p10, EncodingProfilesManager::ProxyClips, true, QStringLiteral("proxy_profile"));
     m_configProxy.proxy_profile_box->addWidget(m_proxyProfiles);
-    addPage(p10, i18n("Proxy Clips"), QStringLiteral("zoom-out"));
+    addPage(p10, i18n("Proxy Clips"), QStringLiteral("transform-scale"));
     connect(m_configProxy.kcfg_generateproxy, &QAbstractButton::toggled, m_configProxy.kcfg_proxyminsize, &QWidget::setEnabled);
     m_configProxy.kcfg_proxyminsize->setEnabled(KdenliveSettings::generateproxy());
     connect(m_configProxy.kcfg_generateimageproxy, &QAbstractButton::toggled, m_configProxy.kcfg_proxyimageminsize, &QWidget::setEnabled);
@@ -491,6 +485,22 @@ void KdenliveSettingsDialog::initJogShuttlePage()
     m_configShuttle.kcfg_enableshuttle->setDisabled(true);
 #endif /* USE_JOGSHUTTLE */
     m_pageJog = addPage(p6, i18n("JogShuttle"), QStringLiteral("dialog-input-devices"));
+#if defined(Q_OS_WIN)
+    m_configShuttle.shuttledisabled->setText(
+        i18n("For device configuration see <a href=\"https://docs.kdenlive.org/user_interface/menu/settings_menu/configure_kdenlive.html#windows\">our "
+             "documentation</a>."));
+    connect(m_configShuttle.shuttledisabled, &QLabel::linkActivated, this, &KdenliveSettingsDialog::openBrowserUrl);
+#endif
+}
+
+void KdenliveSettingsDialog::openBrowserUrl(const QString &url)
+{
+    qDebug() << "=== LINK CLICKED: " << url;
+    auto *job = new KIO::OpenUrlJob(QUrl(url));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
+    // exist in both classes
+    job->start();
 }
 
 void KdenliveSettingsDialog::initTranscodePage()
@@ -1225,6 +1235,15 @@ void KdenliveSettingsDialog::updateSettings()
         fullReset = true;
     }
 
+    if (m_configColors.kcfg_monitorGridH->value() != KdenliveSettings::monitorGridH()) {
+        KdenliveSettings::setMonitorGridH(m_configColors.kcfg_monitorGridH->value());
+        Q_EMIT updateMonitorGrid();
+    }
+    if (m_configColors.kcfg_monitorGridV->value() != KdenliveSettings::monitorGridV()) {
+        KdenliveSettings::setMonitorGridV(m_configColors.kcfg_monitorGridV->value());
+        Q_EMIT updateMonitorGrid();
+    }
+
     if (m_configColors.kcfg_window_background->color() != KdenliveSettings::window_background()) {
         KdenliveSettings::setWindow_background(m_configColors.kcfg_window_background->color());
         Q_EMIT updateMonitorBg();
@@ -1950,18 +1969,7 @@ void KdenliveSettingsDialog::initSpeechPage()
     });
     m_configSpeech.models_url->setText(
         i18n("Download speech models from: <a href=\"https://alphacephei.com/vosk/models\">https://alphacephei.com/vosk/models</a>"));
-    connect(m_configSpeech.models_url, &QLabel::linkActivated, this, [&](const QString &contents) {
-        qDebug() << "=== LINK CLICKED: " << contents;
-        auto *job = new KIO::OpenUrlJob(QUrl(contents));
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#endif
-        // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
-        // exist in both classes
-        job->start();
-    });
+    connect(m_configSpeech.models_url, &QLabel::linkActivated, this, &KdenliveSettingsDialog::openBrowserUrl);
     connect(m_configSpeech.button_add, &QToolButton::clicked, this, [this]() { this->getDictionary(); });
     connect(m_configSpeech.button_delete, &QToolButton::clicked, this, &KdenliveSettingsDialog::removeDictionary);
     connect(this, &KdenliveSettingsDialog::parseDictionaries, this, &KdenliveSettingsDialog::slotParseVoskDictionaries);
