@@ -89,6 +89,7 @@ class KdenliveDoc : public QObject
 public:
     friend class LoadJob;
     friend class TimelineModel;
+    friend class KdenliveTests;
     /** @brief Create a new empty Kdenlive project with the specified profile and requested number of tracks.
      *
      * @param tracks The number of <video, audio> tracks to create in the project.
@@ -327,6 +328,8 @@ public:
     bool checkConsistency();
     /** @brief Returns true if the document is loading or closing */
     bool isBusy() const;
+    /** @brief Returns a valid {fps_num, fps_den} based on a fps */
+    static std::pair<int, int> getFpsFraction(double fps, bool *adjusted);
 
 protected:
     static int next_id; /// next valid id to assign
