@@ -36,6 +36,27 @@ MonitorProxy::MonitorProxy(VideoWidget *parent)
     , m_trimmingFrames2(0)
     , m_boundsCount(0)
 {
+    if (q->m_id == int(Kdenlive::ClipMonitor)) {
+        connect(pCore->bin(), &Bin::clipNameChanged, this, &MonitorProxy::updateClipName);
+    }
+    m_showGrid = KdenliveSettings::showMonitorGrid();
+}
+
+void MonitorProxy::switchGrid()
+{
+    m_showGrid = !m_showGrid;
+    KdenliveSettings::setShowMonitorGrid(m_showGrid);
+    Q_EMIT showGridChanged();
+}
+
+int MonitorProxy::gridH() const
+{
+    return KdenliveSettings::monitorGridH();
+}
+
+int MonitorProxy::gridV() const
+{
+    return KdenliveSettings::monitorGridV();
 }
 
 int MonitorProxy::getPosition() const
@@ -43,6 +64,24 @@ int MonitorProxy::getPosition() const
     return m_position;
 }
 
+void MonitorProxy::updateClipName(int id, const QString newName)
+{
+    for (int i = 0; i < m_lastClipsIds.size(); i++) {
+        if (m_lastClipsIds.at(i).first == id) {
+            m_lastClipsIds.remove(i);
+            m_lastClipsIds.insert(i, {id, newName});
+            m_lastClips.clear();
+            for (int j = 0; j < 4 && j < m_lastClipsIds.size(); j++) {
+                m_lastClips << m_lastClipsIds.at(j).second;
+            }
+            m_clipName = newName;
+            Q_EMIT clipNameChanged();
+            Q_EMIT lastClipsChanged();
+            break;
+        }
+    }
+}
+
 void MonitorProxy::resetPosition()
 {
     m_position = -1;
@@ -97,6 +136,12 @@ bool MonitorProxy::setPositionAdvanced(int pos, bool noAudioScrub)
     return false;
 }
 
+void MonitorProxy::setCursorPosition(int pos)
+{
+    m_position = pos;
+    Q_EMIT positionChanged(pos);
+}
+
 void MonitorProxy::positionFromConsumer(int pos, bool playing)
 {
     if (playing) {
@@ -350,6 +395,14 @@ QString MonitorProxy::toTimecode(int frames) const
     return KdenliveSettings::frametimecode() ? QString::number(frames) : q->frameToTime(frames);
 }
 
+void MonitorProxy::selectClip(int ix)
+{
+    if (ix < m_lastClipsIds.size()) {
+        int cid = m_lastClipsIds.at(ix).first;
+        pCore->bin()->selectClipById(QString::number(cid));
+    }
+}
+
 void MonitorProxy::setClipProperties(int clipId, ClipType::ProducerType type, bool hasAV, const QString &clipName)
 {
     if (clipId != m_clipId) {
@@ -364,6 +417,24 @@ void MonitorProxy::setClipProperties(int clipId, ClipType::ProducerType type, bo
         m_clipType = type;
         Q_EMIT clipTypeChanged();
     }
+    if (!clipName.isEmpty()) {
+        std::pair<int, QString> id = {clipId, clipName};
+        for (int i = 0; i < m_lastClipsIds.size(); i++) {
+            if (m_lastClipsIds.at(i).first == clipId) {
+                m_lastClipsIds.remove(i);
+                break;
+            }
+        }
+        m_lastClipsIds.prepend(id);
+        while (m_lastClipsIds.size() > 4) {
+            m_lastClipsIds.removeLast();
+        }
+        m_lastClips.clear();
+        for (int i = 0; i < 4 && i < m_lastClipsIds.size(); i++) {
+            m_lastClips << m_lastClipsIds.at(i).second;
+        }
+        Q_EMIT lastClipsChanged();
+    }
     if (clipName == m_clipName) {
         m_clipName.clear();
         Q_EMIT clipNameChanged();
@@ -372,6 +443,30 @@ void MonitorProxy::setClipProperties(int clipId, ClipType::ProducerType type, bo
     Q_EMIT clipNameChanged();
 }
 
+void MonitorProxy::clipDeleted(int cid)
+{
+    for (int i = 0; i < m_lastClipsIds.size(); i++) {
+        if (m_lastClipsIds.at(i).first == cid) {
+            m_lastClipsIds.remove(i);
+            m_lastClips.clear();
+            for (int j = 0; j < 4 && j < m_lastClipsIds.size(); j++) {
+                m_lastClips << m_lastClipsIds.at(j).second;
+            }
+            Q_EMIT lastClipsChanged();
+            break;
+        }
+    }
+}
+
+void MonitorProxy::documentClosed()
+{
+    m_lastClipsIds.clear();
+    m_lastClips.clear();
+    m_clipName.clear();
+    Q_EMIT lastClipsChanged();
+    Q_EMIT clipNameChanged();
+}
+
 void MonitorProxy::setAudioThumb(const QList<int> &streamIndexes, const QList<int> &channels)
 {
     m_audioChannels = channels;
@@ -517,7 +612,7 @@ void MonitorProxy::addEffect(const QString &effectData, const QString &effectSou
     QStringList effectInfo = effectSource.split(QLatin1Char(','));
     effectInfo.prepend(effectData);
     if (m_clipId > -1) {
-        QMetaObject::invokeMethod(pCore->bin(), "slotAddEffect", Qt::QueuedConnection, Q_ARG(QString, QString::number(m_clipId)),
+        QMetaObject::invokeMethod(pCore->bin(), "slotAddEffect", Qt::QueuedConnection, Q_ARG(std::vector<QString>, {QString::number(m_clipId)}),
                                   Q_ARG(QStringList, effectInfo));
     } else {
         // Dropped in project monitor
@@ -542,5 +637,5 @@ void MonitorProxy::setJobsProgress(const ObjectId &owner, const QStringList &job
 
 void MonitorProxy::terminateJob(const QString &uuid)
 {
-    pCore->taskManager.discardJob(ObjectId(ObjectType::BinClip, m_clipId, QUuid()), QUuid(uuid));
+    pCore->taskManager.discardJob(ObjectId(KdenliveObjectType::BinClip, m_clipId, QUuid()), QUuid(uuid));
 }
