@@ -8,7 +8,6 @@
 #include "core.h"
 #include "kdenlivesettings.h"
 
-#include "utils/KMessageBox_KdenliveCompat.h"
 #include <KFileItem>
 #include <KIO/FileCopyJob>
 #include <KIO/Global>
@@ -27,8 +26,6 @@
 #include <QToolBar>
 #include <QtConcurrent>
 
-#include <kcompletion_version.h>
-
 ResourceWidget::ResourceWidget(QWidget *parent)
     : QWidget(parent)
     , m_showloadingWarning(true)
